# Database migrations.

These files should be committed to the repo.

Once a migration file has been committed and pushed, it must not be changed (because others may have run it on their db); instead, create a new migration.